==> upload-api-client-internal-2.29.0.tgz: package/src/services/FilesV2Service.ts <==
/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */
import type { AccountId } from "../models/AccountId";
import type { DeleteFileBatchRequestV2 } from "../models/DeleteFileBatchRequestV2";
import type { FileDetails } from "../models/FileDetails";
import type { FilePath } from "../models/FilePath";
import { request as __request } from "../core/request";

export class FilesV2Service {
  /**
   * Gets the full metadata for a file. Required API key type: 'secret_*' or 'public_*'.
   * @param accountId
   * @param filePath
   * @returns FileDetails Success.
   * @throws ApiError
   */
  public static async getFileDetails(accountId: AccountId, filePath: FilePath): Promise<FileDetails> {
    const result = await __request({
      method: "GET",
      path: `/v2/accounts/${accountId}/files/details`,
      query: {
        filePath: filePath
      },
      errors: {
        401: `Unauthenticated.`
      }
    });
    return result.body;
  }

  /**
   * Synchronously deletes a file. Required API key type: 'secret_*' only.
   * @param accountId
   * @param filePath
   * @returns any Success.
   * @throws ApiError
   */
  public static async deleteFile(accountId: AccountId, filePath: FilePath): Promise<any> {
    const result = await __request({
      method: "DELETE",
      path: `/v2/accounts/${accountId}/files`,
      query: {
        filePath: filePath
      },
      errors: {
        401: `Unauthenticated.`
      }
    });
    return result.body;
  }

  /**
   * Asynchronously deletes multiple files. Required API key type: 'secret_*' only.
   * @param accountId
   * @param requestBody
   * @returns void
   * @throws ApiError
   */
  public static async deleteFileBatch(accountId: AccountId, requestBody: DeleteFileBatchRequestV2): Promise<void> {
    const result = await __request({
      method: "DELETE",
      path: `/v2/accounts/${accountId}/files/batch`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }
}

==> upload-api-client-internal-2.39.0.tgz: package/src/services/FilesV2Service.ts <==
/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */
import type { AccountId } from "../models/AccountId";
import type { DeleteFileBatchRequestV2 } from "../models/DeleteFileBatchRequestV2";
import type { FileDetails } from "../models/FileDetails";
import type { FilePath } from "../models/FilePath";
import { request as __request } from "../core/request";

export class FilesV2Service {
  /**
   * Gets the full metadata for a file.
   * @param accountId
   * @param filePath
   * @returns FileDetails Success.
   * @throws ApiError
   */
  public static async getFileDetails(accountId: AccountId, filePath: FilePath): Promise<FileDetails> {
    const result = await __request({
      method: "GET",
      path: `/v2/accounts/${accountId}/files/details`,
      query: {
        filePath: filePath
      },
      errors: {
        401: `Unauthenticated.`
      }
    });
    return result.body;
  }

  /**
   * Synchronously deletes a file.
   * @param accountId
   * @param filePath
   * @returns any Success.
   * @throws ApiError
   */
  public static async deleteFile(accountId: AccountId, filePath: FilePath): Promise<any> {
    const result = await __request({
      method: "DELETE",
      path: `/v2/accounts/${accountId}/files`,
      query: {
        filePath: filePath
      },
      errors: {
        401: `Unauthenticated.`
      }
    });
    return result.body;
  }

  /**
   * Asynchronously deletes multiple files.
   * @param accountId
   * @param requestBody
   * @returns void
   * @throws ApiError
   */
  public static async deleteFileBatch(accountId: AccountId, requestBody: DeleteFileBatchRequestV2): Promise<void> {
    const result = await __request({
      method: "DELETE",
      path: `/v2/accounts/${accountId}/files/batch`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }
}
